@@ -9,11 +9,12 @@ import daiquiri
 import typer
 
 import gitlab
+from dbnomics_fetcher_ops.cli_utils import check_provider_slug_is_lowercase, get_fetcher_def_not_found_error_message
 from gitlab.const import Visibility
 from gitlab.v4.objects import DeployKey, Project, ProjectCommit, ProjectKey, ProjectPipelineSchedule, User
 from gitlab.v4.objects.variables import ProjectVariable
 
-from ..app_args import check_provider_slug_is_lowercase, get_fetcher_def_not_found_error_message
+from ..app_args import get_app_args
 from ..gitlab import init_gitlab_client
 from ..model import FetcherDef, FetcherDefNotFound, FetcherMetadata, FileDef, PipelineV5Config, ScheduleDef
 from ..ssh import generate_ssh_key_pair
@@ -26,18 +27,11 @@ DEFAULT_BRANCH = "master"
 SSH_PRIVATE_KEY = "SSH_PRIVATE_KEY"
 
 
-def configure_command(
-    provider_slug: str = typer.Argument(..., callback=check_provider_slug_is_lowercase),
-    gitlab_private_token: str = typer.Option(
-        ..., envvar="GITLAB_PRIVATE_TOKEN", help="Private access token used to authenticate to GitLab API"
-    ),
-    debug_gitlab: bool = typer.Option(False, help="Show logging debug messages of Python GitLab"),
-):
+def configure(provider_slug: str = typer.Argument(..., callback=check_provider_slug_is_lowercase)):
     """Configure a fetcher."""
-    # Defer import to let the cli.callback function write the variable and avoid importing None.
-    from ..app_args import app_args
-
-    assert app_args is not None
+    app_args = get_app_args()
+    if app_args.gitlab_private_token is None:
+        raise typer.BadParameter("GitLab private token must be given")
 
     try:
         fetcher_def = app_args.fetcher_metadata.find_fetcher_def_by_provider_slug(provider_slug)
@@ -50,9 +44,9 @@ def configure_command(
     try:
         configure_fetcher(
             fetcher_def,
-            debug_gitlab=debug_gitlab,
+            debug_gitlab=app_args.debug_gitlab,
             fetcher_metadata=app_args.fetcher_metadata,
-            gitlab_private_token=gitlab_private_token,
+            gitlab_private_token=app_args.gitlab_private_token,
             pipeline_v5_config=pipeline_v5_config,
         )
     except UnsupportedPipelineVersion as exc:
