@@ -2,10 +2,12 @@ from typing import List
 
 import typer
 
+from dbnomics_fetcher_ops.app_args import get_app_args
+
 from ..model import PipelineVersionError, known_pipeline_versions, validate_pipeline_version
 
 
-def list_command(
+def list_(
     slug: bool = typer.Option(False, help="Print fetcher slug instead of code"),
     pipeline_versions: List[str] = typer.Option([], "--pipeline-version", help="Filter fetchers by pipeline version"),
 ):
@@ -15,10 +17,7 @@ def list_command(
 
     Useful to build another script based on the output.
     """
-    # Defer import to let the cli.callback function write the variable and avoid importing None.
-    from ..app_args import app_args
-
-    assert app_args is not None
+    app_args = get_app_args()
 
     # Validate pipeline versions dynamically because Typer can't take advantage of Literal.
     try:
