@@ -17,12 +17,12 @@ def find_index(predicate: Callable[[T], bool], items: Iterable[T], default=None)
     return next((i for i, item in enumerate(items) if predicate(item)), default)
 
 
-def iter_child_directories(directory: Path, warn_other: bool = False) -> Iterator[Path]:
+def iter_child_directories(directory: Path, *, warn_other: bool = False) -> Iterator[Path]:
     """Iterate over child directories of a directory."""
     for child in directory.iterdir():
         if child.is_dir():
             yield child
-        else:
+        elif warn_other:
             logger.warning("Ignoring %r because it is not a directory", str(child))
 
 
